# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	A tool for creating scanners (text pattern recognizers)
Name:		flex-new
Version:	2.5.36
Release:	1.%{__distinit}%{__distvers}
License:	BSD
Group:		Development/Tools
URL:		http://flex.sourceforge.net/
Source0:	http://downloads.sf.net/flex/flex-%{version}.tar.bz2
Patch0:		flex-2.5.36-bison-2.6.1.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	bison, gettext, m4
Requires:	m4

# Where to put the documentation
%global flexdocdir %{_datadir}/doc/flex-doc-%{version}

%description
The flex program generates scanners. Scanners are programs which can recognize
lexical patterns in text. Flex takes pairs of regular expressions and C code
as input and generates a C source file as output. The output file is compiled
and linked with a library to produce an executable. The executable searches
through its input for occurrences of the regular expressions. When a match is
found, it executes the corresponding C code. Flex was designed to work with
both Yacc and Bison, and is used by many programs as part of their build
process.

Note that the version of flex included in this package is called flex-new
rather than flex, and the header files and libraries have been moved to
%{_includedir}/flex-new and %{_libdir}/flex-new respectively. This is to
enable flex-new to be parallel-installed with the system version of flex
(usually 2.5.4a) and must be taking into account when using this version.

%package doc
Summary:	Documentation for flex scanner generator
Group:		Documentation

%description doc
This package contains documentation for flex scanner generator in
plain text and PDF formats.

%prep
%setup -q -n flex-%{version}

# Fix test failures with bison 2.6
# https://sourceforge.net/tracker/?func=detail&aid=3546447&group_id=97492&atid=618177
%patch0 -p1

%build
%configure --program-suffix=-new --disable-dependency-tracking CFLAGS="-fPIC %{optflags}"
make %{_smp_mflags}

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} docdir=%{flexdocdir} install

# Don't package info file or translations, which could conflict with system flex package
rm -rf %{buildroot}{%{_infodir},%{_datadir}/locale}/

# Remove documents we don't want to package
rm -f %{buildroot}%{flexdocdir}/{README.cvs,TODO}

# Move headers and libraries out of the way of the flex-2.5.4a locations
# so that flex-new can be parallel-installed with it. In order to use
# flex-new, the compiler flags -I%%{_includedir}/flex-new -L%%{_libdir}/flex-new
# are required.
mkdir -p %{buildroot}{%{_includedir},%{_libdir}}/flex-new
mv %{buildroot}%{_includedir}/FlexLexer.h %{buildroot}%{_includedir}/flex-new/
mv %{buildroot}%{_libdir}/libfl{,_pic}.a %{buildroot}%{_libdir}/flex-new/

# Add compatibility symlinks
cd %{buildroot}
ln -s -f flex-new .%{_bindir}/flex-new++
ln -s -f flex-new.1 .%{_mandir}/man1/flex-new++.1
ln -s -f libfl.a .%{_libdir}/flex-new/libl.a
cd -

# Remove unwanted symlinks if present
rm -f  %{buildroot}%{_bindir}/flex++

%check
make check

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING examples/ NEWS ONEWS README THANKS TODO
%{_bindir}/flex-new
%{_bindir}/flex-new++
%{_includedir}/flex-new/
%{_libdir}/flex-new/
%{_mandir}/man1/flex-new.1*
%{_mandir}/man1/flex-new++.1*

%files doc
%defattr(-,root,root,-)
%{_datadir}/doc/flex-doc-%{version}/

%changelog
* Wed Aug  1 2012 Paul Howarth <paul@city-fan.org> 2.5.36-1
- Update to 2.5.36 (#842073)
- Drop flex-2.5.35-sign.patch, flex-2.5.35-hardening.patch,
  flex-2.5.35-gcc44.patch, flex-2.5.35-missing-prototypes.patch
- Add flex-2.5.36-bison-2.6.1.patch
- Add a subpackage doc

* Wed Oct 12 2011 Paul Howarth <paul@city-fan.org> 2.5.35-3
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Jul 27 2010 Paul Howarth <paul@city-fan.org> 2.5.35-2
- Declare yyget_column and yyset_column in reentrant mode (#612465)
- Fix dist tag for RHEL 6 Beta

* Tue Jun 16 2009 Paul Howarth <paul@city-fan.org> 2.5.35-1
- Update to 2.5.35
- Update dist tag macros to global/SLES-compatible versions
- Include patches from Fedora
- * Fix signed/unsigned comparison in the generated code (#445950)
- * Fix warning due to ignoring return value of fwrite() in ECHO macro (#484961)
- * Add missing #include <cstdio> (required by gcc 4.4 - #496548)
- Add m4 dependency (http://flex.sourceforge.net/manual/M4-Dependency.html)
- Build with -fPIC
- Exclude flex.info and translations, which could conflict with system flex package
- Create flex-new++, symlinked to flex-new

* Mon Sep 11 2006 Paul Howarth <paul@city-fan.org> 2.5.33-2
- Fix dist tag for development builds
- Add buildreq m4

* Thu Jul 27 2006 Paul Howarth <paul@city-fan.org> 2.5.33-1
- Create flex-new package, parallel-installable with flex
